SpacePy documentation — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- homepage|
- search|
- documentation »

# SpacePy documentation

SpacePy is a package for Python, targeted at the space sciences, that aims to make basic data analysis, modeling and visualization easier. It builds on the capabilities of the well-known NumPy and MatPlotLib packages. Publication quality output direct from analyses is emphasized among other goals:

> - Quickly obtain data
> - Create publications quality plots
> - Perform complicated analysis easily
> - Run common empirical models
> - Change coordinates effortlessly
> - Harness the power of Python

The SpacePy project seeks to promote accurate and open research standards by providing an open environment for code development. In the space physics community there has long been a significant reliance on proprietary languages that restrict free transfer of data and reproducibility of results. By providing a comprehensive, open-source library of widely-used analysis and visualization tools in a free, modern and intuitive language, we hope that this reliance will be diminished.

When publishing research which used SpacePy, please provide appropriate credit to the SpacePy team via citation or acknowledgment.

To cite SpacePy in publications, use (BibTeX code):
  @INPROCEEDINGS{spacepy11, author = {{Morley}, S.~K. and {Koller}, J. and {Welling}, D.~T. and {Larsen}, B.~A. and {Henderson}, M.~G. and {Niehof}, J.~T.}, title = “{Spacepy - A Python-based library of tools for the space sciences}”, booktitle = “{Proceedings of the 9th Python in science conference (SciPy 2010)}”, year = 2011, address = {Austin, TX} }

Certain modules may provide additional citations in the `__citation__` attribute. Contact a module’s author (details in the `__citation__` attribute) before publication or public presentation of analysis performed by that module, or in case of questions about the module. This allows the author to validate the analysis and receive appropriate credit for his or her work.

# SpacePy Documents

- Installing SpacePy
- SpacePy - A Quick Start Documentation
- Documentation Standard
- SpacePy Python Programming Tips
- SpacePy Configuration
- SpacePy Case Studies
- Publication List

# SpacePy Code

- coordinates - module for coordinate transforms
- datamodel - easy to use general data model
- data assimilation - data assimilation module
- empiricals - module with heliospheric empirical modules
- irbempy - Python interface to irbem/ONERA library
- lanlstar - module to calculate Lstar or Lmax using artificial neural network
- omni - module to read and process NASA OMNIWEB data
- plot - Plot, various specialized plotting functions and associated utilities
- PoPPy - Point Processes in Python
- pycdf - Python interface to CDF files
- radbelt - Functions supporting radiation belt diffusion codes
- SeaPy - Superposed Epoch in Python
- time - Time conversion, manipulation and implementation of Ticktock class
- toolbox - Toolbox of various functions and generic utilities

## Indices and tables

- Index
- Module Index
- Search Page

Release: | 0.1.5
Doc generation date:
| December 23, 2014

### Navigation

- index
- modules |
- modules |
- next |
- homepage|
- search|
- documentation »